pub struct HeaderRef<'a> { /* private fields */ }Expand description
A view of a section header whose bytes are owned by the containing File.
Implementations
Sourceimpl<'a> HeaderRef<'a>
impl<'a> HeaderRef<'a>
Sourcepub fn is_legacy(&self) -> bool
pub fn is_legacy(&self) -> bool
Return true if this is a header like [legacy.subsection], or false otherwise.
Sourcepub fn subsection_name(&self) -> Option<&'a BStr>
pub fn subsection_name(&self) -> Option<&'a BStr>
Return the subsection name, if present, i.e. “origin” in [remote "origin"].
Sourcepub fn name(&self) -> &'a BStr
pub fn name(&self) -> &'a BStr
Return the name of the header, like “remote” in [remote "origin"].
Sourcepub fn to_bstring(&self) -> BString
pub fn to_bstring(&self) -> BString
Serialize this header view into a BString for convenience.