SectionRef

Struct SectionRef 

pub struct SectionRef<'a> { /* private fields */ }
A section in a git-config file, like [core] or [remote "origin"], along with all of its keys.

This is a view into data owned by its File.

Implementations

Source

impl<'file> SectionRef<'file>

Access

pub fn to_owned(self) -> Section

Copy this view into a self-contained owned section.

pub fn header(&self) -> HeaderRef<'file>

Return our header.

pub fn id(&self) -> SectionId

Return the unique id of the section, for use with the *_by_id() family of methods in gix_config::File.

pub fn body(&self) -> BodyRef<'file>

Return our body, containing all value names and values.

pub fn to_bstring(&self) -> BString

Serialize this type into a BString for convenience.

Note that to_string() can also be used, but might not be lossless.

pub fn write_to(&self, out: &mut dyn Write) -> Result<()>

Stream ourselves to the given out, in order to reproduce this section mostly losslessly as it was parsed.

pub fn meta(&self) -> &'file Metadata

Return additional information about this sections origin.

pub fn value(&self, value_name: impl AsRef<str>) -> Option<BString>

Retrieves the last matching value in this section with the given value name, if present.

pub fn value_implicit(&self, value_name: &str) -> Option<Option<BString>>

Retrieves the last matching value in this section, including implicit values.

pub fn values(&self, value_name: &str) -> Vec<BString>

Retrieves all values that have the provided value name.

pub fn value_names(&self) -> impl Iterator<Item = String> + '_

Returns an iterator visiting all value names in order.

pub fn contains_value_name(&self, value_name: &str) -> bool

Returns true if the section contains the provided value name.